#! /bin/sh
#
# Copyright (c) 2001 by James A. McQuillan (McQuillan Systems)
# Copyright (c) 2000 by Stephan Lauffer
# Copyright (c) 2000 by Georg Baum
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# MCQUILLAN SYSTEMS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
# OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# 11/28/2001 -Jim McQuillan- Updated version to 3.0.0
#
# 09/16/2001 -Jim McQuillan- Updated for LTSP 2.09pre2
#
# 05/08/2001 -Jim McQuillan- RH 7.1 now puts commandline options for syslogd
#             in a file called /etc/sysconfig/syslog.
#             Also, added code to check for the existance of the /etc/X11/xdm
#             /etc/X11/gdm directories, to see if it should attempt to
#             configure them.
#
# 04/24/2001 -Jim McQuillan- Updated to 2.08 for Redhat 7.1
#
# 01/13/2001 -Jim McQuillan- Updated to 2.06 for Redhat
#             Fixed problem where inetd.tmpl and Xservers.tmpl
#             had incorrect '.sh' suffix.
#
# 10/29/2000 -Jim McQuillan- Updated to 2.04 for Redhat
# 10/26/2000 -Georg Baum- first version for Debian
# 08/10/2000 -Jim McQuillan- Updated for ltsp version 2.01
# 08/09/2000 -Stephan Lauffer - minor updates and changes
#             for "multi-distribution support"
# 08/05/2000 -Jim McQuillan- Updated for ltsp version 2.0
# 02/13/2000 -Jim McQuillan- New script to build
#             an LTSP environment on a server
#
##############################################################################


##############################################################################
#
# Read the global settings... and set some other stuff...
#

. ./CONFIG

#
# we support several displaymanagers. No matter which one is used, we install
# our own files (Xsetup_workstation and ltsp.gif) into the xdm directory, 
# because that simplifies the handling a bit. 
#
# X_DISPLAYMANAGERS is the list of supported displaymanagers. If you make any 
# changes here, make sure that the code below which sets up 
# /etc/X11/xdm/Xaccess, /etc/X11/xdm/Xservers, /etc/X11/xdm/xdm-config and 
# /etc/inittab and the gdm config files still works.
#
# X_DISPLAYMANAGERS is currently not used for redhat
#
# wdm not tested!  (Taken out for redhat)
#
X_DISPLAYMANAGERS="xdm kdm gdm"

#
# determine the actual used displaymanager
#
DM_RUNNING=no

DFLT_RUNLEVEL=`awk -F: '/^id:.:initdefault/ { print $2 }' /etc/inittab`
if [ "${DFLT_RUNLEVEL}" -eq 5 ]; then
    DM_RUNNING=yes
fi

#
##############################################################################

##############################################################################
#
# Read functions...
#
. ./install_functions.sh

#
# prevent logit() from rotating the logfile once more, since this was already
# done by install.sh
#
export LOGINIT="Y"

#
##############################################################################

##############################################################################
#
# We check what's the name of this file. I want to offer a way to use 
# different sysmlinks to this file which helps us to change some
# stuff if necessary... 
#
SCRIPT_NAME=`basename $0`
VERSION=`echo $0 | sed 's/\.sh//g' | cut -s -f2 -d-`

##############################################################################
#
# Create the templates for the files listed in the SOURCE_* variables above
#
# We will place them in ${TMPL_DIR}, so that a sysadmin can
# review them before putting them in place.
#
# We build a bunch of small shell scripts to do the work.  The sysadmin
# can then take a look at the scripts and modify them if they like, before
# executing them with the ltsp_initialize script
#

#------------------------------------------------------------------------------
#
# Create an updated /etc/exports file
#
# If the current exports file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
SOURCE=/etc/exports
TARGET=${TMPL_DIR}/exports.tmpl
logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This file was taken from this server and modified to contain "
    echo "# entries for an LTSP workstation."
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
    echo "# and place them where the TARGET variable is pointing to."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"The config file for nfs\""
    echo "DESC_KEY=exports"
    echo ""
    echo 'if [ -f ${TARGET} ]; then'
    echo '    FILENUM=1'
    echo '    while :; do'
    echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
    echo '            FILENUM=`expr ${FILENUM} + 1`'
    echo '        else'
    echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
    echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
    echo '            break'
    echo '        fi'
    echo '    done'
    echo 'fi'
    echo ""
    echo 'cat <<EOF >${TARGET}'
) >${TARGET}

#
# If the /etc/exports file already exists, then we will get a copy of it,
# stripping out the original LTSP stuff.  This needs to be better, it should
# actually preserve the existing LTSP stuff.
#
if [ -f ${SOURCE} ]; then
    logit "Using original ${SOURCE} file as the base"
    sed '/## LTS-begin ##/,/## LTS-end ##/d' <${SOURCE} >>${TARGET}
fi

(
    echo "## LTS-begin ##"
    echo
    echo "#"
    echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
    echo "# on: ${TODAY} by the ltsp installation script."
    echo "# For more information, visit the ltsp homepage"
    echo "# at http://www.ltsp.org"
    echo "#"
    echo
    echo "${ROOT_DIR}                  ${IP_NETWORK}/${IP_NETMASK}(ro,no_root_squash)"
    echo "${SWAP_DIR}         ${IP_NETWORK}/${IP_NETMASK}(rw,no_root_squash)"
    echo
    echo "#"
    echo "# The following entries need to be uncommented if you want"
    echo "# Local App support in ltsp"
    echo "#"
    echo "#/home                  ${IP_NETWORK}/${IP_NETMASK}(rw,no_root_squash)"
    echo
    echo "## LTS-end ##"
) >>${TARGET}

(
    echo "EOF"
    echo ""
    echo 'chmod 0644 ${TARGET}'
    echo "killall -HUP rpc.nfsd > /dev/null 2>&1"
    echo "killall -HUP rpc.mountd > /dev/null 2>&1"
    echo "exit 0"
) >>${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Display Managers
#
# There are several to choose from.  Redhat usually ships with
# xdm, kdm and gdm.
#
# We are going to setup all of them, in case the sysadm wants to
# change which display manager is being used.
#


################################################################################
#
# #     # ######  #     #               #         #    #  ######  #     #
#  #   #  #     # ##   ##              #          #   #   #     # ##   ##
#   # #   #     # # # # #             #           #  #    #     # # # # #
#    #    #     # #  #  #            #            ###     #     # #  #  #
#   # #   #     # #     #           #             #  #    #     # #     #
#  #   #  #     # #     #          #              #   #   #     # #     #
# #     # ######  #     #         #               #    #  ######  #     #
# 
#------------------------------------------------------------------------------
#
# Update the /etc/X11/xdm/xdm-config file
#
# On Redhat, both xdm and kdm use the same configuration directory
#
# If the current xdm-config file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
if [ -d /etc/X11/xdm ]; then
    SOURCE=/etc/X11/xdm/xdm-config
    TARGET=${TMPL_DIR}/xdm-config.tmpl

    logit "Setting up ${TARGET}"

    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file was taken from this server and modified to setup "
        echo "# a workstation Startup script for an LTSP workstation"
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"The main config file for xdm/kdm\""
        echo "DESC_KEY=xdm-config"

        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo "cat <<'EOF' >\${TARGET}"
    ) >${TARGET}

    #
    # If the /etc/X11/xdm/xdm-config file already exists, then we will get a 
    # copy of it, stripping out the original LTSP stuff.  This needs to be better, 
    # it should actually preserve the existing LTSP stuff.
    #
    if [ -f ${SOURCE} ]; then
        logit "Using original ${SOURCE} file as the base"
        sed 's/^DisplayManager\.requestPort/# DisplayManager.requestPort/
            /## LTS-begin ##/,/## LTS-end ##/d
            ' <${SOURCE} >>${TARGET}
    fi

    (
        echo "## LTS-begin ##"
        echo
        echo "#"
        echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
        echo "# on: ${TODAY} by the ltsp installation script."
        echo "# For more information, visit the ltsp homepage"
        echo "# at http://www.ltsp.org"
        echo "#"
        echo
        echo "DisplayManager.*.setup:     /etc/X11/xdm/Xsetup_workstation"
        echo
        echo "## LTS-end ##"
    ) >>${TARGET}

    (
        echo "EOF"
        echo ""
        echo "chmod 0444 \${TARGET}"
        echo ""
        echo "exit 0"
    ) >>${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

    #------------------------------------------------------------------------------
    #
    # Create the /etc/X11/xdm/Xsetup_workstation file
    #
    # If there is already an Xsetup_workstation file, save it
    #
    SOURCE=/etc/X11/xdm/Xsetup_workstation
    TARGET=${TMPL_DIR}/Xsetup_workstation.tmpl

    logit "Setting up ${TARGET}"

    (
        echo "#!/bin/sh"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file created fresh to setup "
        echo "# a workstation startup script for an LTSP workstation"
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"Sets the logo of your login window\""
        echo "DESC_KEY=Xsetup_workstation"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo "cat <<'EOF' >\${TARGET}"
    ) >${TARGET}

    (
        echo "#!/bin/sh"
        echo "## LTS-begin ##"
        echo
        echo "#"
        echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
        echo "# on: ${TODAY} by the ltsp installation script."
        echo "# For more information, visit the ltsp homepage"
        echo "# at http://www.ltsp.org"
        echo "#"
        echo
        echo '/usr/X11R6/bin/xsetroot -solid "#356390"'
        echo 'if [ -x /usr/bin/xsri ]; then'
        echo '    /usr/bin/xsri -geometry +5+5 -avoid 300x250 -keep-aspect \'
        echo '        /etc/X11/xdm/ltsp.gif'
        echo 'fi'
        echo
        echo "## LTS-end ##"
    ) >>${TARGET}

    (
        echo "EOF"
        echo ""
        echo 'chmod 0755 ${TARGET}'
        echo "exit 0"
    ) >>${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

    #------------------------------------------------------------------------------
    #
    # Modify the /etc/X11/xdm/Xservers file
    #

    #
    # If ${DM_RUNNING} = yes then they are already
    # running a display manager, so we don't want to change
    # the Xservers file, because that would disable X on the console.
    # If they are ${DM_RUNNING} = no, then we should comment out the
    # line in this file, so that X doesn't startup on the console
    # automatically later when we start the display manager.
    #

    if [ "${DM_RUNNING}" = "no" ]; then

        SOURCE=/etc/X11/xdm/Xservers
        TARGET=${TMPL_DIR}/Xservers.tmpl
        logit "Setting up ${TARGET}"
    
        (
            echo ":"
            echo "#"
            echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
            echo "#"
            echo "# This file was taken from this server and modified to either"
            echo "# enable or disable the GUI login on the console, depending"
            echo "# wether xdm/kdm was already running or not."
            echo "#"
            echo "# This shell script is normally run by the ltsp_initialize script."
            echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
            echo "# and place them where the TARGET variable is pointing to."
            echo "#"
            echo ""
            echo "TARGET=${SOURCE}"
            echo "DEFAULT=Y"
            echo "DESCRIPTION=\"Config file for xdm to launch local Xserver\""
            echo "DESC_KEY=Xservers"
            echo ""
            echo 'if [ -f ${TARGET} ]; then'
            echo '    FILENUM=1'
            echo '    while :; do'
            echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
            echo '            FILENUM=`expr ${FILENUM} + 1`'
            echo '        else'
            echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
            echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
            echo '            break'
            echo '        fi'
            echo '    done'
            echo 'fi'
            echo ""
            echo "cat <<'EOF' >\${TARGET}"
        ) >${TARGET}

        sed 's/^:0/# :0/' <${SOURCE} >>${TARGET}
        (
            echo "#"
            echo "# The above line for starting an X server on display :0"
            echo "# was commented out on: ${TODAY} by the ltsp installation"
            echo "# script."
            echo "# For more information, visit the ltsp homepage"
            echo "# at http://www.ltsp.org"
            echo "#"
        ) >>${TARGET}

        (
            echo "EOF"
            echo ""
            echo 'chmod 0444 ${TARGET}'
            echo "exit 0"
        ) >>${TARGET}

        chmod 0644      ${TARGET}
        chown root:root ${TARGET}
    fi

    #------------------------------------------------------------------------------
    #
    # Copy the ltsp.gif logo file
    #
    SOURCE=${TMPL_DIR}/ltsp.gif
    DEST=/etc/X11/xdm/ltsp.gif
    TARGET=${TMPL_DIR}/ltsplogo.tmpl

    logit "Setting up ${TARGET}"

    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file created fresh to setup "
        echo "# a workstation startup script for an LTSP workstation"
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "SOURCE=${SOURCE}"
        echo "TARGET=${DEST}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"The background logo for your login\""
        echo "DESC_KEY=ltsp.gif"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
    ) >${TARGET}

    echo 'cp ${SOURCE}    ${TARGET}' >>${TARGET}

    (
        echo ""
        echo 'chmod 0644 ${TARGET}'
        echo "exit 0"
    ) >>${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

    #------------------------------------------------------------------------------
    #
    # Modify the /etc/X11/xdm/Xaccess file
    #
    # If the current Xaccess file does not contain any mention
    # of ltsp, then we can just add the new entries to the end.
    # If it does contain entries from a previous ltsp installation,
    # then we need to save the file and create a new one.
    #
    SOURCE=/etc/X11/xdm/Xaccess
    TARGET=${TMPL_DIR}/Xaccess.tmpl
    logit "Setting up ${TARGET}"

    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file was taken from this server and modified to allow remote "
        echo "# X terminals to get an xdm/kdm login prompt"
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"The config file to allow remote xdm logins\""
        echo "DESC_KEY=Xaccess"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo "cat <<'EOF' >\${TARGET}"
    ) >${TARGET}


    #
    # If the /etc/X11/xdm/Xaccess file already exists, then we will get a
    # copy of it, stripping out the original LTSP stuff.  This needs to be better, 
    # it should actually preserve the existing LTSP stuff.
    #
    if [ -f ${SOURCE} ]; then
        sed 's/^# \*/\*/
             /## LTS-begin ##/,/## LTS-end ##/d' <${SOURCE} >>${TARGET}
    else
        (
            echo "## LTS-begin ##"
            echo
            echo "#"
            echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
            echo "# on: ${TODAY} by the ltsp installation script."
            echo "# For more information, visit the ltsp homepage"
            echo "# at http://www.ltsp.org"
            echo "#"
            echo
            echo "*          #any host can get a login window" >>${TARGET}
            echo
            echo "## LTS-end ##"
        ) >>${TARGET}
    fi

    (
        echo "EOF"
        echo ""
        echo 'chmod 0444 ${TARGET}'
        echo "exit 0"
    ) >>${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}
fi

################################################################################
#
#    #####  ######  #     #
#   #     # #     # ##   ##
#   #       #     # # # # #
#   #  #### #     # #  #  #
#   #     # #     # #     #
#   #     # #     # #     #
#    #####  ######  #     #
#
#------------------------------------------------------------------------------
#
# Update the /etc/X11/gdm/Init/Default file
#
# When gdm detects an Xserver contacting it for a login,
# it looks in the /etc/X11/xdm/Init directory for a file
# that matches the value of the $DISPLAY environment variable.
# For instance, the Xserver running on the server would have
# a DISPLAY variable set to ':0', so gdm will look for a file
# called '/etc/X11/xdm/Init/:0'.  If it doesn't find that file
# then it will look for a file called '/etc/X11/xdm/Init/Default'
# and use that instead.
#
# On Redhat, the Init/Default file is really just a symbolic link
# to the /etc/X11/xdm/Xsetup_0 script.
#
# Our ltsp configuration script will rename 'Default' to ':0'
# so that the Xserver running on the console will continue to
# appear the same.
#
# To handle the workstations, we will create a new symlink 
# called 'Default' and point it to /etc/X11/xdm/Xsetup_workstation
# 

if [ -d /etc/X11/gdm ]; then
    SOURCE=/etc/X11/gdm/Init/Default
    TARGET=${TMPL_DIR}/gdm_Init_Default.tmpl
    
    if [ -d /etc/X11/gdm/Init ]; then
        (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"The gdm startup script\""
        echo "DESC_KEY=gdm_Init_Default"
    
        echo ""
        echo "# If there was already a :0 file, then leave it alone"
        echo "# Normally, we will rename the Default file to :0, unless"
        echo "# a :0 file already exists, in which case, we will leave the "
        echo "# :0 file alone and remove the Default file"
        echo ""
        echo 'if [ -f ${TARGET} -o -L ${TARGET} ]; then'
        echo ''
        echo '    #'
        echo '    # We have to test -L also, because -f returns false for a symlink'
        echo '    # which points to a nonexistant file.'
        echo '    #'
        echo '    if [ -f /etc/X11/gdm/Init/:0 -o -L /etc/X11/gdm/Init/:0 ]; then'
        echo '        FILENUM=1'
        echo '        while :; do'
        echo '            if [ -f "${TARGET}.${FILENUM}" -o -L ${TARGET}.${FILENUM} ]; then'
        echo '                FILENUM=`expr ${FILENUM} + 1`'
        echo '            else'
        echo '                echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '                if test -L ${TARGET}; then'
        echo ''
        echo '                    #'
        echo '                    # if the symlink points to a nonexistant file,'
        echo '                    # the mv command will fail, so create a new symlink.'
        echo '                    #'
        echo "                    ln -sf \`perl -e 'print(readlink $ARGV[0]);' \${TARGET}\` \${TARGET}.\${FILENUM}"
        echo '                    rm -f ${TARGET}'
        echo '                else'
        echo '                    mv ${TARGET} ${TARGET}.${FILENUM}'
        echo '                fi'
        echo '                break'
        echo '            fi'
        echo '        done'
        echo '    else'
        echo '        echo "Saving old ${TARGET} as /etc/X11/gdm/Init/:0"'
        echo '        if test -L ${TARGET}; then'
        echo "            ln -sf \`perl -e 'print(readlink $ARGV[0]);' ${TARGET}\` /etc/X11/gdm/Init/:0"
        echo '            rm -f ${TARGET}'
        echo '        else'
        echo '            mv  ${TARGET} /etc/X11/gdm/Init/:0'
        echo '        fi'
        echo '    fi'
        echo 'fi'
        echo ''
        echo 'ln -s ../../xdm/Xsetup_workstation /etc/X11/gdm/Init/Default'
        echo ''
        echo "exit 0"
        ) >${TARGET}
    fi
    
    chmod 0644      ${TARGET}
    chown root:root ${TARGET}
    
    #------------------------------------------------------------------------------
    #
    # Modify the /etc/X11/gdm/gdm.conf file
    #
    # If the current gdm.conf file does not contain any mention
    # of ltsp, then we can just add the new entries to the end.
    # If it does contain entries from a previous ltsp installation,
    # then we need to save the file and create a new one.
    #
    
    if [ -f /etc/X11/gdm/gdm.conf ]; then
    
        SOURCE=/etc/X11/gdm/gdm.conf
        TARGET=${TMPL_DIR}/gdm.conf.tmpl
        logit "Setting up ${TARGET}"
    
        (
            echo ":"
            echo "#"
            echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
            echo "#"
            echo "# This file was taken from this server and modified to allow remote "
            echo "# X terminals to get an gdm login prompt"
            echo "#"
            echo "# This shell script is normally run by the ltsp_initialize script."
            echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
            echo "# and place them where the TARGET variable is pointing to."
            echo "#"
            echo ""
            echo "TARGET=${SOURCE}"
            echo "DEFAULT=Y"
            echo "DESCRIPTION=\"The config file for gdm\""
            echo "DESC_KEY=gdm.conf"
            echo ""
            echo 'if [ -f ${TARGET} ]; then'
            echo '    FILENUM=1'
            echo '    while :; do'
            echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
            echo '            FILENUM=`expr ${FILENUM} + 1`'
            echo '        else'
            echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
            echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
            echo '            break'
            echo '        fi'
            echo '    done'
            echo 'fi'
            echo ""
            echo "cat <<'EOF' >\${TARGET}"
        ) >${TARGET}
    
        #
        # If the /etc/X11/gdm/gdm.conf file already exists, then we will get a
        # copy of it, stripping out the original LTSP stuff.  This needs to be better, 
        # it should actually preserve the existing LTSP stuff.
        #
        # Todo: the begin- and end lines are not added yet by gdm-change.pl!
        #
        if [ "${DM_RUNNING}" = "yes" ]; then
            ./gdm-change.pl < ${SOURCE} | sed \
                 '/## LTS-begin ##/,/## LTS-end ##/d' >>${TARGET}
        else
            ./gdm-change.pl < ${SOURCE} | sed 's/^0=/# 0=/g
                 /## LTS-begin ##/,/## LTS-end ##/d' >>${TARGET}
        fi
    
        (
            echo "EOF"
            echo ""
            echo 'chmod 0444 ${TARGET}'
            echo ""
            echo "exit 0"
        ) >>${TARGET}
    
        chmod 0644      ${TARGET}
        chown root:root ${TARGET}
    
    fi
fi

################################################################################
#
# Setup the /etc/hosts.allow file
#
# If the current /etc/hosts.allow file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
SOURCE=/etc/hosts.allow
TARGET=${TMPL_DIR}/hosts.allow.tmpl
logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This file was taken from this server and modified to allow"
    echo "# workstations to obtain an IP address via bootp and mount "
    echo "# filesystems via NFS"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
    echo "# and place them where the TARGET variable is pointing to."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Configuration file for tcp wrappers\""
    echo "DESC_KEY=hosts.allow"
    echo ""
    echo 'if [ -f ${TARGET} ]; then'
    echo '    FILENUM=1'
    echo '    while :; do'
    echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
    echo '            FILENUM=`expr ${FILENUM} + 1`'
    echo '        else'
    echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
    echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
    echo '            break'
    echo '        fi'
    echo '    done'
    echo 'fi'
    echo ""
    echo "cat <<'EOF' >\${TARGET}"
) >${TARGET}

#
# If the /etc/hosts.allow file already exists, then we will get a
# copy of it, stripping out the original LTSP stuff.  This needs to be better, 
# it should actually preserve the existing LTSP stuff.
#
if [ -f ${SOURCE} ]; then
    logit "Using original ${SOURCE} file as the base"
    sed '/## LTS-begin ##/,/## LTS-end ##/d' <${SOURCE} >>${TARGET}
fi

(
    echo "## LTS-begin ##"
    echo
    echo "#"
    echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
    echo "# on: ${TODAY} by the ltsp installation script."
    echo "# For more information, visit the ltsp homepage"
    echo "# at http://www.ltsp.org"
    echo "#"
    echo
    echo "bootpd:    0.0.0.0"
    echo "in.tftpd:  ${IP_NETWORK_BASE}."
    echo "portmap:   ${IP_NETWORK_BASE}."
    echo
    echo "## LTS-end ##"
) >>${TARGET}

(
    echo "EOF"
    echo ""
    echo 'chmod 0644 ${TARGET}'
    echo "exit 0"
) >>${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Setup the syslog startup script
#
if [ "${VERSION}" = "7.1" ]; then
    SOURCE=/etc/sysconfig/syslog
    TARGET=${TMPL_DIR}/syslog.tmpl
    logit "Setting up ${TARGET}"

    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file was taken from this server and modified to allow"
        echo "# a remote workstation to send syslog output to this server"
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"Startup info for syslogd\""
        echo "DESC_KEY=syslogd"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo "cat <<'EOF' >\${TARGET}"
    ) >${TARGET}

    sed 's/SYSLOGD_OPTIONS=\"-m 0\"/SYSLOGD_OPTIONS=\"-m 0 -r\"/' \
               <${SOURCE} >>${TARGET}

    (
        echo "EOF"
        echo ""
        echo 'chmod 0644 ${TARGET}'
        echo "exit 0"
    ) >>${TARGET}
else
    SOURCE=/etc/rc.d/init.d/syslog
    TARGET=${TMPL_DIR}/syslog.tmpl
    logit "Setting up ${TARGET}"

    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file was taken from this server and modified to allow"
        echo "# a remote workstation to send syslog output to this server"
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"Startup script for syslogd\""
        echo "DESC_KEY=syslogd"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo "cat <<'EOF' >\${TARGET}"
    ) >${TARGET}

    sed 's/daemon syslogd -m 0[     ]*$/daemon syslogd -m 0 -r/' \
               <${SOURCE} >>${TARGET}

    (
        echo "EOF"
        echo ""
        echo 'chmod 0755 ${TARGET}'
        echo "exit 0"
    ) >>${TARGET}
fi

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Setup tftpd in inetd or xinetd
#
# RedHat 7.0/7.1 uses xinetd but all of the older versions of Redhat use inetd
#

if [ "${VERSION}" = "7.0" -o "${VERSION}" = "7.1" ]; then
    SOURCE=/etc/xinetd.d/tftp
    TARGET=${TMPL_DIR}/tftpd.tmpl
    logit "Setting up ${TARGET}"

    (
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will enable the tftp service"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Enable the tftp daemon\""
    echo "DESC_KEY=xinetd_tftpd"
    echo ""
    echo "chkconfig tftp on"
    echo "exit 0"
    ) >${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}
else
    SOURCE=/etc/inetd.conf
    TARGET=${TMPL_DIR}/inetd.tmpl
    logit "Setting up ${TARGET}"

    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This file was taken from this server and modified to allow"
        echo "# tftp to run, so it can serve up kernels for workstations."
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"Config file for inetd\""
        echo "DESC_KEY=inetd_tftpd"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo 'if command -v update-inetd > /dev/null 2>&1; then'
        echo '    update-inetd --enable tftp'
        echo ''
        echo '#'
        echo '#'
        echo '# You can either use bootp or dhcp to tell the workstations their'
        echo '# ip-addresses. If you decide to use bootp, you may want to uncomment'
        echo '# the following line:'
        echo '#'
        echo ''
        echo '#    update-inetd --enable bootps'
        echo ''
        echo 'else'
        echo ''
        echo '#'
        echo '# this should not happen, but just in case, here follows the manual way'
        echo '#'
        echo ''
        echo "    cat <<'EOF'>\${TARGET}"
    ) >${TARGET}

    logit "Using original ${SOURCE} file as the base"
    sed 's/^# *tftp[ 	]/tftp	/' <${SOURCE} >>${TARGET}

    (
        echo "EOF"
        echo ""
        echo '    chmod 0644 ${TARGET}'
        echo "fi"
        echo "exit 0"
    ) >>${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}
fi

#------------------------------------------------------------------------------
#
# Change the default runlevel in the inittab file so that a
# display manager will start when the system boots.
#

SOURCE=/etc/inittab
TARGET=${TMPL_DIR}/inittab.tmpl
logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This file was taken from this server and modified to allow"
    echo "# xdm to run, so that a remote workstation can login."
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
    echo "# and place them where the TARGET variable is pointing to."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Config file for init\""
    echo "DESC_KEY=inittab"
    echo ""
    echo 'if [ -f ${TARGET} ]; then'
    echo '    FILENUM=1'
    echo '    while :; do'
    echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
    echo '            FILENUM=`expr ${FILENUM} + 1`'
    echo '        else'
    echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
    echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
    echo '            break'
    echo '        fi'
    echo '    done'
    echo 'fi'
    echo ""
    echo "cat <<'EOF' >\${TARGET}"
) >${TARGET}


#
# If we are running Redhat 7.0/7.1, then we can just use whatever
# display manager is configured.  For older versions, we
# will change it to use xdm.
#
if [ "${VERSION}" = "7.0" -o "${VERSION}" = "7.1" ]; then
    sed 's/^id:3:initdefault/id:5:initdefault/
        ' <${SOURCE} >>${TARGET}
else
    sed '/^[^#].*prefdm/s/^/# /
         /^[^#].*kdm/s/^/# /
         /^[^#].*gdm/s/^/# /
         /^[^#].*xdm/s/^/# /
         s/^id:3:initdefault/id:5:initdefault/
        ' <${SOURCE} >>${TARGET}
    (
        echo "#"
        echo "# The following 'xdm' line was added ${TODAY}"
        echo "# by the ltsp installation script"
        echo "#"
        echo "x:5:respawn:/usr/X11R6/bin/xdm -nodaemon"
    ) >>${TARGET}
fi

(
    echo "EOF"
    echo ""
    echo 'chmod 0644 ${TARGET}'
    echo "exit 0"
) >>${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Setup the rc scripts so that portmapper will start when server boots
#

SOURCE=/etc/rc.d/rc5.d/S13portmap
TARGET=${TMPL_DIR}/portmap.tmpl
logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will check to see if there is a startup script"
    echo "# to start the nfs daemon"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Startup links for portmapper\""
    echo "DESC_KEY=portmap"
    echo ""
    echo "chkconfig --level 5 portmap on"
    echo "exit 0"
) >${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Setup the rc scripts so that nfs will start when server boots
#
SOURCE=/etc/rc.d/rc5.d/S60nfs
TARGET=${TMPL_DIR}/nfs.tmpl
logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will check to see if there is a startup script"
    echo "# to start the nfs daemon"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Startup links for nfs\""
    echo "DESC_KEY=nfs"
    echo ""
    echo "chkconfig --level 5 nfs on"
    echo "exit 0"
) >${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Create an example dhcpd config file
#
SOURCE=/etc/dhcpd.conf.example
TARGET=${TMPL_DIR}/dhcpd.tmpl
logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This file is an example dhcpd.conf file, to help setup"
    echo "# a DHCP server"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
    echo "# and place them where the TARGET variable is pointing to."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Example config file for dhcp\""
    echo "DESC_KEY=dhcpd.conf"
    echo ""
    echo 'if [ -f ${TARGET} ]; then'
    echo '    FILENUM=1'
    echo '    while :; do'
    echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
    echo '            FILENUM=`expr ${FILENUM} + 1`'
    echo '        else'
    echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
    echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
    echo '            break'
    echo '        fi'
    echo '    done'
    echo 'fi'
    echo ""
    echo "cat <<'EOF' >\${TARGET}"
) >${TARGET}

if [ "${VERSION}" = "7.1" ]; then
    (
        echo "# Sample configuration file for ISCD dhcpd"
        echo "#"
        echo "# Don't forget to set run_dhcpd=1 in /etc/init.d/dhcpd"
        echo "# once you adjusted this file and copied it to /etc/dhcpd.conf."
        echo "#"
        echo
        echo "default-lease-time            21600;"
        echo "max-lease-time                21600;"
        echo
        echo "option subnet-mask            ${IP_NETMASK};"
        echo "option broadcast-address      ${IP_BROADCAST};"
        echo "option routers                ${IP_SERVER};"
        echo "option domain-name-servers    ${IP_SERVER};"
        echo "option domain-name            \"yourdomain.com\";"
        echo "option root-path              \"${IP_SERVER}:${ROOT_DIR}\";"
        echo
        echo "shared-network WORKSTATIONS {"
        echo "    subnet ${IP_NETWORK} netmask ${IP_NETMASK} {"
        echo "    }"
        echo "}"
        echo
        echo "group	{"
        echo "    use-host-decl-names       on;"
        echo "    option log-servers        ${IP_SERVER};"
        echo ""
        echo "    host ws001 {"
        echo "        hardware ethernet     00:E0:06:E8:00:84;"
        echo "        fixed-address         ${IP_NETWORK_BASE}.1;"
        echo "        filename              \"/lts/vmlinuz-2.4.9-ltsp-6\";"
        echo "        option option-128     e4:45:74:68:00:00;"
        echo "        option option-129     \"NIC=eepro100\";"
        echo "    }"
        echo "    host ws002 {"
        echo "        hardware ethernet     00:D0:09:30:6A:1C;"
        echo "        fixed-address         ${IP_NETWORK_BASE}.2;"
        echo "        filename              \"/lts/vmlinuz-2.4.9-ltsp-6\";"
        echo "        option option-128     e4:45:74:68:00:00;"
        echo "        option option-129     \"NIC=eepro100\";"
        echo "    }"
        echo "}"
    ) >>${TARGET}
else
    (
        echo "# Sample configuration file for ISCD dhcpd"
        echo "#"
        echo "# Don't forget to set run_dhcpd=1 in /etc/init.d/dhcpd"
        echo "# once you adjusted this file and copied it to /etc/dhcpd.conf."
        echo "#"
        echo
        echo "default-lease-time            21600;"
        echo "max-lease-time                21600;"
        echo
        echo "option subnet-mask            ${IP_NETMASK};"
        echo "option broadcast-address      ${IP_BROADCAST};"
        echo "option routers                ${IP_SERVER};"
        echo "option domain-name-servers    ${IP_SERVER};"
        echo "option domain-name            \"yourdomain.com\";"
        echo "option root-path              \"${IP_SERVER}:${ROOT_DIR}\";"
        echo
        echo "shared-network WORKSTATIONS {"
        echo "    subnet ${IP_NETWORK} netmask ${IP_NETMASK} {"
        echo "    }"
        echo "}"
        echo
        echo "group	{"
        echo "    use-host-decl-names       on;"
        echo "    option log-servers        ${IP_SERVER};"
        echo ""
        echo "    host ws001 {"
        echo "        hardware ethernet     00:E0:06:E8:00:84;"
        echo "        fixed-address         ${IP_NETWORK_BASE}.1;"
        echo "        filename              \"${TFTP_DIR}/lts/vmlinuz-2.4.9-ltsp-6\";"
        echo "        option option-128     e4:45:74:68:00:00;"
        echo "        option option-129     \"NIC=eepro100\";"
        echo "    }"
        echo "    host ws002 {"
        echo "        hardware ethernet     00:D0:09:30:6A:1C;"
        echo "        fixed-address         ${IP_NETWORK_BASE}.2;"
        echo "        filename              \"${TFTP_DIR}/lts/vmlinuz-2.4.9-ltsp-6\";"
        echo "        option option-128     e4:45:74:68:00:00;"
        echo "        option option-129     \"NIC=eepro100\";"
        echo "    }"
        echo "}"
    ) >>${TARGET}
fi

(
    echo "EOF"
    echo ""
    echo 'chmod 0644 ${TARGET}'

    if [ "${VERSION}" = "7.0" -o "${VERSION}" = "7.1" ]; then
        echo "if [ ! -f /var/lib/dhcp/dhcpd.leases ]; then"
        echo '    echo "Creating new dhcpd.leases file"'
        echo "    >/var/lib/dhcp/dhcpd.leases"
        echo "fi"
    else
        echo "if [ ! -f /var/state/dhcp/dhcpd.leases ]; then"
        echo '    echo "Creating new dhcpd.leases file"'
        echo "    >/var/state/dhcp/dhcpd.leases"
        echo "fi"
    fi

    echo ""
    echo "chkconfig --level 5 dhcpd on"
    echo ""
    echo "exit 0"

) >>${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}
#
##############################################################################

##############################################################################
#
# ok, seems to me we are finished!
#
logit "\nDone with $0\n"
#
if [ "${QUIET_MODE}" != "Y" ]; then
    echo
    echo "Take a look in ${LOGFILE} for a complete log of the installation"
    echo
    echo "You now need to change to the ${TMPL_DIR} directory and"
    echo "run the ltsp_initialize script to complete the installation"
    echo
fi
#
##############################################################################
