:

#
# Copyright (c) 2001 by James A. McQuillan (McQuillan Systems)
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# MCQUILLAN SYSTEMS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
# OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# 01/03/2002 -Jim McQuillan - merged in patch from Michael Collins for
#                             the Conectiva-release file.
#
# 12/17/2001 -Jim McQuillan - Copied install.sh to install_rpm.sh
#
# This script will setup the templates scripts when installed via RPM.
#
##############################################################################

###############################################################################
#
# Detecting server architecture and distributuion release
#

if [ -f /etc/SuSE-release ]; then

    DISTRO_NAME="SuSE"
    DISTRO_VERSION=`grep "VERSION" /etc/SuSE-release | sed s/'VERSION = '//`
    TEMPLATE_FILE="suse-${DISTRO_VERSION}.sh"

elif [ -f /etc/debian_version ]; then

    DISTRO_NAME="Debian GNU/Linux" 
    #
    # a Debian version may be a codename. So we convert from
    # uppercase to lowercase. Additionally we have to convert
    # versions like "testing/unstable" in something that can be
    # part of a filename, so we convert "/" to "_", too.
    #
    DISTRO_VERSION=`tr \[A-Z\]/ \[a-z\]_ < /etc/debian_version`
    TEMPLATE_FILE="debian-${DISTRO_VERSION}.sh"

elif [ -f /etc/mandrake-release ]; then

    DISTRO_NAME="Mandrake"
    DISTRO_VERSION=`awk '{ print $4 }' /etc/mandrake-release`
    TEMPLATE_FILE="mandrake-${DISTRO_VERSION}.sh"

elif [ -f /etc/redhat-release ]; then

    DISTRO_NAME="RedHat" 
    DISTRO_VERSION=`awk '{ print $5 }' /etc/redhat-release`
    TEMPLATE_FILE="redhat-${DISTRO_VERSION}.sh"

elif [ -f /etc/conectiva-release ]; then

    DISTRO_NAME="Conectiva" 
    DISTRO_VERSION=`awk '{ print $3 }' /etc/conectiva-release`
    TEMPLATE_FILE="conectiva-${DISTRO_VERSION}.sh"

elif [ -f /etc/.installed ]; then

    DISTRO_NAME="Caldera" 
    DISTRO_VERSION=`awk -F- '/OpenLinux/ { print $2 }' /etc/.installed`
    TEMPLATE_FILE="caldera-${DISTRO_VERSION}.sh"

fi

#
# so if we have found a well known DISTRO, post a short
# message and start the second script
#
if [ -z "${DISTRO_VERSION}" ] && [ -z "${DISTRO_NAME}" ]; then

   echo "Sorry, there is currently no support for this platform :-("
   exit   
else
    if test -f ./${TEMPLATE_FILE}; then
	:
##	echo "Good! We have found ${DISTRO_NAME} version ${DISTRO_VERSION}"
    else
	echo "Sorry, but ${DISTRO_NAME} version ${DISTRO_VERSION} not supported :-("
	exit
    fi
fi
#
##############################################################################


##############################################################################
#
# Read the global settings...
#
. ./CONFIG

#
##############################################################################

##############################################################################
#
# Read some functions that are used by this script
# install.conf has to be read already!
#
. ./install_functions.sh

###############################################################################
#
# Create updated configuration files on the server
#
# We will place them in ${LTSP_DIR}/templates, so that an sysadmin can
# review them before putting them in place.
#
# We build a bunch of small shell scripts to do the work.  The sysadmin
# can then take a look at the scripts and modify them if they like, before
# executing them with the ltsp_initialize script
#

TARGET=${TMPL_DIR}

if [ -d ${TARGET} ]; then
    FILENUM=1
    while :; do
        if [ -e "${TARGET}.${FILENUM}" ]; then
            FILENUM=`expr ${FILENUM} + 1`
        else
            logit "Saving old ${TARGET} as ${TARGET}.${FILENUM}"
            mv ${TARGET} ${TARGET}.${FILENUM}
            break
        fi
    done
fi

logit "Creating ${TARGET} to hold system config file templates"
mkdir           ${TARGET}
chmod 0755      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Put a README file in the template directory, giving the sysadmin a clue
# as to what he should do with the files in that directory
#

TARGET=${TMPL_DIR}/README

cat <<"EOF" >${TARGET}
The Linux Terminal Server Project (http://www.ltsp.org)

The files in this directory are modified copies of the
system configuration files.

If this server is an LTSP supported platform, such
as Redhat 6.0, 6.1 or 6.2, then you should be able to
run the './ltsp_initialize' script and it will put all 
of the config files in their proper place.

Other platforms may require some modification of these files
and/or their locations to install properly.


*** WARNING *** *** WARNING *** *** WARNING *** *** WARNING *** *** WARNING ***

    Some of the configuration files that are modified by these
    templates, or the ltsp_initialize script could open up security
    holes in the system.  Especially the /etc/hosts.allow and /etc/exports
    files.

    If you are just trying to install LTSP on a server that is NOT
    connected to the internet and you understand the security
    issues, and don't care about it for this server, then go ahead
    and run the ltsp_initialize script and it should setup the server
    for you.

    Otherwise, you can make the modifications yourself, using these
    files as a guideline.
EOF

#------------------------------------------------------------------------------
#
# Copy the ltsp_initialize script into the templates directory
#

SOURCE=ltsp_initialize
TARGET=${TMPL_DIR}/ltsp_initialize

cp ${SOURCE}    ${TARGET}

chmod 0755      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Copy the desc.txt script into the templates directory
#

SOURCE=desc.txt
TARGET=${TMPL_DIR}/desc.txt

cp ${SOURCE}    ${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Copy the ltsp logo file into the templates directory
#

SOURCE=ltsp.gif
TARGET=${TMPL_DIR}/ltsp.gif

cp ${SOURCE}    ${TARGET}

chmod 0644      ${TARGET}
chown root:root ${TARGET}

#------------------------------------------------------------------------------
#
# Start building templates
#

QUIET_MODE="Y"; export QUIET_MODE

/bin/sh ./${TEMPLATE_FILE}

#------------------------------------------------------------------------------
#
# Build the lts.conf file, based on some of the CONFIG variables
#
sed "s^IP_SERVER^${IP_SERVER}^" \
      <${ROOT_DIR}/etc/lts.orig >${ROOT_DIR}/etc/lts.conf

#------------------------------------------------------------------------------
# Write some of the important config items to the /etc/ltsp.conf file,
# so that additional installations can use those values
#
CONF=/etc/ltsp.conf

echo ":"                                      >${CONF}
echo "#"                                     >>${CONF}
echo "# Configuration variables for LTSP"    >>${CONF}
echo "#"                                     >>${CONF}
echo                                         >>${CONF}
echo "LTSP_DIR=${LTSP_DIR}"                  >>${CONF}
echo                                         >>${CONF}

##############################################################################
#
# Make sure the ${SWAP_DIR} directory exists
#
if [ ! -d "${SWAP_DIR}" ]; then
    logit "Creating ${SWAP_DIR} directory"
    mkdir -p ${SWAP_DIR}
    chmod 0777 ${SWAP_DIR}
    chown root:root ${SWAP_DIR}
fi

#
