#! /bin/sh
#
# LTSP: Copyright (c) 2001 by James A. McQuillan (McQuillan Systems)
#
# This module is written by Stephan Lauffer
#
# 06/05/2002 -Stephan Peuckert- Added support for SuSE 8.0
# 05/05/2002 -Jim McQuillan- Added support for Suse 7.2 and 7.3
# 11/28/2001 -Jim McQuillan- Updated version to 3.0.0
# 09/16/2001 -Jim McQuillan- Updated for LTSP 2.09pre2
#
# 05/08/2001 -Jim McQuillan- Added code to check for existence of the
#             /etc/X11/xdm and /etc/X11/kdm directories.
# Version: 0.1 	last modify: 12/31/2000 georg
# 12/31/2000 -Georg-: Added preliminary support for SuSE 7.1 (assuming it works 
#                     like 7.0 and corrected some typos.
#
#Note: All the rc.config changing scripts only work if the variable they want 
#      to change is already present.
#      This is the case when the appropriate packages (dhcpd etc) are installed
#      already.
#      For the rpm package, this could be handled by dependencies, but for
#      the tgz package we have to do something better here.
# 
version="0.2"
#
# Description:
#    Copyright (C) 2000 Stephan Lauffer <lauffer@ph-freiburg.de>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

echo 
echo "Start building SuSE configuration templates."
echo "Version $version"
echo
echo "Feel free to report any bugs and make additional changes."
echo "Please post them to discuss@ltsp.org"
echo 
echo "[press Enter to continue]"
read

##############################################################################
#
# Read the global settings... and set some other stuff...
#
. ./CONFIG
#
##############################################################################

##############################################################################
#
# Read functions...
#
. ./install_functions.sh

# prevent logit() from rotating the logfile once more, since this was already
# done by install.sh
export LOGINIT="Y"
#
##############################################################################

##############################################################################
#
# We check what's the name of this file. I want to offer a way to use 
# different sysmlinks to this file which helps us to change some
# stuff if necessary... 
#
SCRIPT_NAME=`basename $0`
VERSION=`echo $0 | sed 's/\.sh//g' | cut -s -f2 -d-`

if [ "${VERSION}" = "7.0" \
  -o "${VERSION}" = "7.1" \
  -o "${VERSION}" = "7.2" \
  -o "${VERSION}" = "7.3" \
  -o "${VERSION}" = "8.0" ]; then
	XDM_DIR="/etc/X11/xdm"
else
	XDM_DIR="/usr/X11R6/lib/X11/xdm"
fi
#
#############################################################################

##############################################################################
#
# Create the templates for the files listed in the SOURCE_* variables above
#
# We will place them in ${TMPL_DIR}, so that a sysadmin can
# review them before putting them in place.
#
# We build a bunch of small shell scripts to do the work.  The sysadmin
# can then take a look at the scripts and modify them if they like, before
# executing them with the ltsp_initialize script
#

#------------------------------------------------------------------------------
#
# Create an updated /etc/exports file
#
# If the current exports file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
SOURCE=/etc/exports
TARGET=${TMPL_DIR}/exports.tmpl
logit "Setting up ${TARGET}"

#
# If the /etc/exports file already exists, then we will get a copy of it,
# stripping out the original LTSP stuff.  This needs to be better, it should
# actually preserve the existing LTSP stuff.
#
(
    echo "## LTS-begin ##"
    echo "#"
    echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
    echo "# on: ${TODAY} by the ltsp installation script."
    echo "# For more information, visit the ltsp homepage"
    echo "# at http://www.ltsp.org"
    echo "# DESCRIPTION=Config file for nfs"
    echo "# DESC_KEY=exports"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# ACTION=COPY,0644,root,root"
    echo "#"
    echo "${ROOT_DIR}                  ${IP_NETWORK}/${IP_NETMASK}(ro,no_root_squash)"
    echo "${SWAP_DIR}         ${IP_NETWORK}/${IP_NETMASK}(rw,no_root_squash)"
    echo "#"
    echo "# The following entries need to be uncommented if you want"
    echo "# Local App support in ltsp"
    echo "#"
    echo "#/home                  ${IP_NETWORK}/${IP_NETMASK}(rw,no_root_squash)"
    echo "#"
    echo "## LTS-end ##"
) >${TARGET}

if [ -f ${SOURCE} ]; then
    logit "Using original ${SOURCE} file as the base"
    sed '/## LTS-begin ##/,/## LTS-end ##/d' <${SOURCE} >>${TARGET}
fi

#------------------------------------------------------------------------------
#
# Display Managers
#
# There are several to choose from.  Debian usually ships with
# xdm, kdm, wdm and gdm.
# While xdm, kdm and wdm all have the same config files (but in different
# directories), gdm uses a completely different scheme.
#
# We are going to setup all of them, in case the sysadm wants to
# change which display manager is being used.
#


#------------------------------------------------------------------------------
#
# Update the /etc/X11/xdm/xdm-config file
#
# If the current xdm-config file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
if [ -d ${XDM_DIR} ]; then
    SOURCE=${XDM_DIR}/xdm-config
    TARGET=${TMPL_DIR}/xdm-config.tmpl
    logit "Setting up ${TARGET}"
    
    #
    # If the /etc/X11/${DM}/xdm-config file already exists, then we will get a 
    # copy of it, stripping out the original LTSP stuff.  This needs to be better, 
    # it should actually preserve the existing LTSP stuff.
    #
    (
    echo "#!/usr/bin/perl -w"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=\"The main config file for XDM\""
    echo "# DESC_KEY=xdm-config"
    echo "# ACTION=BACKUP_EXECUTE"
    echo "#"
    echo "# Open config file read only, change what we need to and store it in"
    echo '# $file. Then close this config file and rewrite it new with'
    echo '# the stuff from $file.'
    echo "#"
    echo "open (FILE,\"<${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo "#"
    echo 'while ($line = <FILE>) {'
    echo '	chomp($line);'
    echo '	$line =~ s/^DisplayManager\.requestPort:.*/## LTS-begin ##\n\! DisplayManager\.requestPort:	0\n## LTS-end ##\n/;'
    echo '	$file .= $line . "\n";'
    echo "}"
    echo "#"
    echo "#"close FILE;
    echo "#"
    echo "open (FILE,\">${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo 'print FILE "$file";'
    echo "close FILE;"
    ) >${TARGET}
    
    #------------------------------------------------------------------------------
    #
    # Create the /etc/X11/xdm/Xsetup file
    #
    # If there is already an Xsetup file, save it
    #
    #SOURCE=/etc/X11/xdm/Xsetup
    #TARGET=${TMPL_DIR}/Xsetup.pl
    #logit "Setting up ${TARGET}"
    #
    #(
    #echo "#!/usr/bin/perl -w"
    #echo "# TARGET=${SOURCE}"
    #echo "# DEFAULT=N"
    #echo "# DESCRIPTION=Configure xdm to allow any host"
    #echo "# ACTION=BACKUP_EXECUTE"
    #echo "#"
    #echo "# Open config file read only, change what we need to and store it in"
    #echo '# $file. Then close this config file and rewrite it new with'
    #echo '# the stuff from $file.'
    #echo "#"
    #echo "open (FILE,\"<${SOURCE}\")"
    #echo '	or die "\n$!\n";'
    #echo "#"
    #echo 'while ($line = <FILE>) {'
    #echo '	chomp($line);'
    #echo '	if ($line =~ /^\s*background=\$\{XDMDIR\}\/BackGround\.xpm/) {'
    #echo '		$line = "## LTS-begin ##\n  background=\$\{XDMDIR\}/ltsp.gif\n## LTS-end ##\n";'
    #echo '	}'
    #echo '	$file .= $line . "\n";'
    #echo "}"
    #echo "#"
    #echo "#"close FILE;
    #echo "#"
    #echo "open (FILE,\">${SOURCE}\")"
    #echo '	or die "\n$!\n";'
    #echo 'print FILE "$file";'
    #echo "close FILE;"
    #) >${TARGET}
    
    #------------------------------------------------------------------------------
    #
    # Copy the ltsp.gif logo file
    #
    #SOURCE=${ROOT_DIR}/etc/X11/xdm/ltsp.gif
    #DEST=/etc/X11/xdm/ltsp.gif
    #TARGET=${TMPL_DIR}/ltsplogo.sh
    #
    #logit "Setting up ${TARGET}"
    #
    #(
    #    echo ":"
    #    echo "#"
    #    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    #    echo "#"
    #    echo "# This file created fresh to setup "
    #    echo "# a workstation startup script for an LTSP workstation"
    #    echo "#"
    #    echo "# This shell script is normally run by the ltsp_initialize script."
    #    echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
    #    echo "# and place them where the TARGET variable is pointing to."
    #    echo "#"
    #    echo ""
    #    echo "SOURCE=${SOURCE}"
    #    echo "TARGET=${DEST}"
    #    echo "DEFAULT=N"
    #    echo "DESCRIPTION=\"The logo for your login screen\""
    #    echo ""
    #    echo 'if [ -f ${TARGET} ]; then'
    #    echo '    FILENUM=1'
    #    echo '    while :; do'
    #    echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
    #    echo '            FILENUM=`expr ${FILENUM} + 1`'
    #    echo '        else'
    #    echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
    #    echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
    #    echo '            break'
    #    echo '        fi'
    #    echo '    done'
    #    echo 'fi'
    #    echo ""
    #) >${TARGET}
    #
    #echo 'cp ${SOURCE}    ${TARGET}' >>${TARGET}
    #
    #(
    #    echo ""
    #    echo 'chmod 0644 ${TARGET}'
    #) >>${TARGET}
    #
    #chmod 0644      ${TARGET}
    #chown root:root ${TARGET}
    
    #------------------------------------------------------------------------------
    #
    # Modify the /etc/X11/xdm/Xaccess file
    #
    # If the current Xaccess file does not contain any mention
    # of ltsp, then we can just add the new entries to the end.
    # If it does contain entries from a previous ltsp installation,
    # then we need to save the file and create a new one.
    #
    SOURCE=${XDM_DIR}/Xaccess
    TARGET=${TMPL_DIR}/Xaccess.tmpl
    logit "Setting up ${TARGET}"
    
    (
    echo "#!/usr/bin/perl -w"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=Configure xdm to allow any host"
    echo "# DESC_KEY=Xaccess"
    echo "# ACTION=BACKUP_EXECUTE"
    echo "#"
    echo "# Open config file read only, change what we need to and store it in"
    echo '# $file. Then close this config file and rewrite it new with'
    echo '# the stuff from $file.'
    echo "#"
    echo "open (FILE,\"<${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo "#"
    echo 'while ($line = <FILE>) {'
    echo '	chomp($line);'
    echo '	$line =~ s/^#\s*\*.*#(.*)/## LTS-begin ##\n\*	# $1\n## LTS-end ##\n/;'
    echo '	$file .= $line . "\n";'
    echo "}"
    echo "#"
    echo "#"close FILE;
    echo "#"
    echo "open (FILE,\">${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo 'print FILE "$file";'
    echo "close FILE;"
    ) >${TARGET}
fi

#------------------------------------------------------------------------------
# KDE3
# Modify the /etc/opt/kde3/share/config/kdm/kdmrc file
# From kde 2.2 on, kdm does not use most of the xdm compatible files anymore.
# Instead, it stores everything in the file kdmrc.
#
# If the current kdmrc file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
    
if [ -d /etc/opt/kde3/share/config/kdm ]; then
    SOURCE=/etc/opt/kde3/share/config/kdm/kdmrc
    TARGET=${TMPL_DIR}/kdm3rc.tmpl
    logit "Setting up ${TARGET}"
    
    (
        echo ":"
        echo "#"
        echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
        echo "#"
        echo "# This shell script is normally run by the ltsp_initialize script."
        echo "# It will take the lines between the 'cat <<' line and the 'EOF' line"
        echo "# and place them where the TARGET variable is pointing to."
        echo "#"
        echo ""
        echo "TARGET=${SOURCE}"
        echo "DEFAULT=Y"
        echo "DESCRIPTION=\"The configuration file for kdm (K Display Manager)\""
        echo "DESC_KEY=kdmrc"
        echo ""
        echo 'if [ -f ${TARGET} ]; then'
        echo '    FILENUM=1'
        echo '    while :; do'
        echo '        if [ -f "${TARGET}.${FILENUM}" ]; then'
        echo '            FILENUM=`expr ${FILENUM} + 1`'
        echo '        else'
        echo '            echo "Saving old ${TARGET} as ${TARGET}.${FILENUM}"'
        echo '            cp  ${TARGET}  ${TARGET}.${FILENUM}'
        echo '            break'
        echo '        fi'
        echo '    done'
        echo 'fi'
        echo ""
        echo "cat <<'EOF' >\${TARGET}"
    ) >${TARGET}
    
    #
    # If the /etc/opt/kde3/share/config/kdm/kdm.conf file already exists, then we will get a
    # copy of it, stripping out the original LTSP stuff.  This needs to be better, 
    # it should actually preserve the existing LTSP stuff.
    #
    # Todo: the begin- and end lines are not added yet by kdm-change.pl!
    #
    if [ -f ${SOURCE} ]; then
        if test "${DM_RUNNING}" = "yes"; then
            ./kdm-change.pl < ${SOURCE} | sed \
		'/## LTS-begin ##/,/## LTS-end ##/d' >>${TARGET}
        else
            ./kdm-change.pl < ${SOURCE} | sed 's/^0=/# 0=/g
		/## LTS-begin ##/,/## LTS-end ##/d' >>${TARGET}
        fi
    else
	(
	    echo "## LTS-begin ##"
    	    echo
    	    echo "#"
    	    echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
    	    echo "# on: ${TODAY} by the ltsp installation script."
    	    echo "# For more information, visit the ltsp homepage"
    	    echo "# at http://www.ltsp.org"
    	    echo "#"
    	    echo
    	    echo '[Xdmcp]'
	    echo 'Enable=true'
    	    echo
    	    echo "## LTS-end ##"
	) >>${TARGET}
    fi
    
    (
        echo "EOF"
        echo ""
        echo 'chmod 0444 ${TARGET}'
    ) >>${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}
    
fi


#------------------------------------------------------------------------------
#
# Setup the /etc/hosts.allow file
#
# If the current /etc/hosts.allow file does not contain any mention
# of ltsp, then we can just add the new entries to the end.
# If it does contain entries from a previous ltsp installation,
# then we need to save the file and create a new one.
#
SOURCE=/etc/hosts.allow
TARGET=${TMPL_DIR}/hosts.allow.tmpl
logit "Setting up ${TARGET}"

#
# If the /etc/hosts.allow file already exists, then we will get a
# copy of it, stripping out the original LTSP stuff.  This needs to be better, 
# it should actually preserve the existing LTSP stuff.
#
(
    echo "## LTS-begin ##"
    echo
    echo "#"
    echo "# The lines between the 'LTS-begin' and the 'LTS-end' were added"
    echo "# on: ${TODAY} by the ltsp installation script."
    echo "# For more information, visit the ltsp homepage"
    echo "# at http://www.ltsp.org"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=\"Config file for tcp wrappers\""
    echo "# DESC_KEY=hosts.allow"
    echo "# ACTION=COPY,0644,root,root"
    echo "#"
    echo
    echo "bootpd:    0.0.0.0"
    echo "in.tftpd:  ${IP_NETWORK_BASE}."
    echo "portmap:   ${IP_NETWORK_BASE}."
    echo
    echo "## LTS-end ##"
) >${TARGET}

if [ -f ${SOURCE} ]; then
    logit "Using original ${SOURCE} file as the base"
    sed '/## LTS-begin ##/,/## LTS-end ##/d' <${SOURCE} >>${TARGET}
fi

#------------------------------------------------------------------------------
# INETD
#
# Setup the rc scripts so that inetd will start when server boots
# creates softlink in rc.d to start the inetd
# there is no more rc.config in SuSE 8.0

if [ "$VERSION" = "8.0" ]; then

    SOURCE=/etc/rc.d/rc5.d/S20inetd
    TARGET=${TMPL_DIR}/inetd.tmpl
    logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will check to see if there is a startup script"
    echo "# to start the inet daemon"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Startup links for inetd\""
    echo "DESC_KEY=inetd"
    echo ""
    echo "chkconfig inetd 35"
    echo "exit 0"
    ) >${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

else

#------------------------------------------------------------------------------
#
# Setup the rc.config to start inetd for SuSE < 7.3
#
    SOURCE=/etc/rc.config
    TARGET=${TMPL_DIR}/inetd.tmpl
    logit "Setting up ${TARGET}"

    (
    echo "#!/usr/bin/perl -w"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=Enable inetd in rc.config"
    echo "# DESC_KEY=rc.config_inetd"
    echo "# ACTION=BACKUP_EXECUTE"
    echo "#"
    echo "# Open config file read only, change what we need to and store it in"
    echo '# $file. Then close this config file and rewrite it new with'
    echo '# the stuff from $file.'
    echo "#"
    echo "open (FILE,\"<${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo "#"
    echo 'while ($line = <FILE>) {'
    echo '	chomp($line);'
    echo '	if ( $line =~ /^START_INETD\s*=\s*\"?.*/) {'
    echo "		\$line =\"START_INETD=\\\"yes\\\"\";"
    echo '	}'
    echo '	$file .= $line . "\n";'
    echo "}"
    echo "#"
    echo "close FILE;"
    echo "#"
    echo "open (FILE,\">${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo 'print FILE "$file";'
    echo "close FILE;"
    ) >${TARGET}
fi


#------------------------------------------------------------------------------
# SYSLOG
#
# Setup the syslog startup script
# SuSE 8.0 	This will be done in /etc/sysconfig/syslog   
# SuSE < 7.3 	This will be done in /etc/rc.config   
# 

if [ "$VERSION" = "8.0" ]; then
    SOURCE=/etc/sysconfig/syslog
else
    SOURCE=/etc/rc.config
fi     

    TARGET=${TMPL_DIR}/syslogd.tmpl
    logit "Setting up ${TARGET}"

    (
echo "#!/usr/bin/perl -w"
echo "# TARGET=${SOURCE}"
echo "# DEFAULT=Y"
echo "# DESCRIPTION=Configure syslogd for remote access"
echo "# DESC_KEY=rc.config_syslogd"
echo "# ACTION=BACKUP_EXECUTE"
echo "#"
echo "# Open config file read only, change what we need to and store it in"
echo '# $file. Then close this config file and rewrite it new with'
echo '# the stuff from $file.'
echo "#"
echo "open (FILE,\"<${SOURCE}\")"
echo '	or die "\n$!\n";'
echo "#"
echo 'while ($line = <FILE>) {'
echo '	chomp($line);'
echo '	if ( $line =~ /^SYSLOGD_PARAMS\s*=\s*\"?.*/) {'
echo "		\$line =\"SYSLOGD_PARAMS=\\\"-m 0 -r -s ${IP_NETWORK}/${IP_BROADCAST}\\\"\";"
echo '	}'
echo '	$file .= $line . "\n";'
echo "}"
echo "#"
echo "close FILE;"
echo "#"
echo "open (FILE,\">${SOURCE}\")"
echo '	or die "\n$!\n";'
echo 'print FILE "$file";'
echo "close FILE;"
) >${TARGET}


#------------------------------------------------------------------------------
#
# Modify the /etc/inetd.conf file to start the bootpd
#
SOURCE=/etc/inetd.conf
TARGET=${TMPL_DIR}/bootpd.tmpl
logit "Setting up ${TARGET}"

(
echo "#!/usr/bin/perl -w"
echo "# TARGET=${SOURCE}"
echo "# DEFAULT=N"
echo "# DESCRIPTION=Start bootpd from inetd"
echo "# DESC_KEY=inetd_bootpd"
echo "# ACTION=BACKUP_EXECUTE"
echo "#"
echo "# Open config file read only, change what we need to and store it in"
echo '# $file. Then close this config file and rewrite it new with'
echo '# the stuff from $file.'
echo "#"
echo "open (FILE,\"<${SOURCE}\")"
echo '	or die "\n$!\n";'
echo "#"
echo 'while ($line = <FILE>) {'
echo '	chomp($line);'
echo '	$line =~ s/^#\s*bootps/bootps/;'
echo '	$file .= $line . "\n";'
echo "}"
echo "#"
echo "#"close FILE;
echo "#"
echo "open (FILE,\">${SOURCE}\")"
echo '	or die "\n$!\n";'
echo 'print FILE "$file";'
echo "close FILE;"
) >${TARGET}

#------------------------------------------------------------------------------
#
# Modify the /etc/inetd.conf file to start the tftp
#
SOURCE=/etc/inetd.conf
TARGET=${TMPL_DIR}/tftp.tmpl
logit "Setting up ${TARGET}"

(
echo "#!/usr/bin/perl -w"
echo "# TARGET=${SOURCE}"
echo "# DEFAULT=Y"
echo "# DESCRIPTION=Start tftpd from inetd"
echo "# DESC_KEY=inetd_tftpd"
echo "# ACTION=BACKUP_EXECUTE"
echo "#"
echo "# Open config file read only, change what we need to and store it in"
echo '# $file. Then close this config file and rewrite it new with'
echo '# the stuff from $file.'
echo "#"
echo "open (FILE,\"<${SOURCE}\")"
echo '	or die "\n$!\n";'
echo "#"
echo 'while ($line = <FILE>) {'
echo '	chomp($line);'
echo '	$line =~ s/^#\s*tftp/tftp/;'
echo '	$file .= $line . "\n";'
echo "}"
echo "#"
echo "#"close FILE;
echo "#"
echo "open (FILE,\">${SOURCE}\")"
echo '	or die "\n$!\n";'
echo 'print FILE "$file";'
echo "close FILE;"
) >${TARGET}


#------------------------------------------------------------------------------
# PORTMAPPER
#
# Setup the rc scripts so that portmapper will start when server boots
# creates softlink in rc.d to start the portmapper
# there is no more rc.config in SuSE 8.0

if [ "$VERSION" = "8.0" ]; then

    SOURCE=/etc/rc.d/rc5.d/S13portmap
    TARGET=${TMPL_DIR}/portmapper.tmpl
    logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will check to see if there is a startup script"
    echo "# to start the portmap daemon"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Startup links for portmapper\""
    echo "DESC_KEY=portmap"
    echo ""
    echo "chkconfig portmap 35"
    echo "exit 0"
    ) >${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

else

#------------------------------------------------------------------------------
#
# Setup the portmapper in rc.config for SuSE < 7.3
#
    SOURCE=/etc/rc.config
    TARGET=${TMPL_DIR}/portmapper.tmpl
    logit "Setting up ${TARGET}"

    (
    echo "#!/usr/bin/perl -w"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=Start portmapper from rc.config"
    echo "# DESC_KEY=rc.config_portmapper"
    echo "# ACTION=BACKUP_EXECUTE"
    echo "#"
    echo "# Open config file read only, change what we need to and store it in"
    echo '# $file. Then close this config file and rewrite it new with'
    echo '# the stuff from $file.'
    echo "#"
    echo "open (FILE,\"<${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo "#"
    echo 'while ($line = <FILE>) {'
    echo '	chomp($line);'
    echo '	$line =~ s/^START_PORTMAP\s*=\s*"?[Nn][Oo]"?.*/START_PORTMAP="yes"/;'
    echo '	$file .= $line . "\n";'
    echo "}"
    echo "#"
    echo "#"close FILE;
    echo "#"
    echo "open (FILE,\">${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo 'print FILE "$file";'
    echo "close FILE;"
    ) >${TARGET}
fi

#------------------------------------------------------------------------------
# NFS-SERVER
#
# Setup the rc scripts so that nfsserver will start when server boots
# creates softlink in rc.d to start the nfsserver
# there is no more rc.config in SuSE 8.0

if [ "$VERSION" = "8.0" ]; then

    SOURCE=/etc/rc.d/rc5.d/S11nfsserver
    TARGET=${TMPL_DIR}/nfs.tmpl
    logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will check to see if there is a startup script"
    echo "# to start the nfsserver"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Startup links for nfsserver\""
    echo "DESC_KEY=nfsserver"
    echo ""
    echo "chkconfig nfsserver 35"
    echo "exit 0"
    ) >${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

else

#------------------------------------------------------------------------------
#
# Setup the nfs-server in rc.config for SuSE < 7.3
#
    SOURCE=/etc/rc.config
    TARGET=${TMPL_DIR}/nfs.tmpl
    logit "Setting up ${TARGET}"

    (
    echo "#!/usr/bin/perl -w"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=Start NFS-Server in rc.config"
    echo "# DESC_KEY=rc.config_nfs"
    echo "# ACTION=BACKUP_EXECUTE"
    echo "#"
    echo "# Open config file read only, change what we need to and store it in"
    echo '# $file. Then close this config file and rewrite it new with'
    echo '# the stuff from $file.'
    echo "#"
    echo "open (FILE,\"<${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo "#"
    echo 'while ($line = <FILE>) {'
    echo '	chomp($line);'
    echo '	$line =~ s/^NFS_SERVER\s*=.*/NFS_SERVER="yes"/;'
    echo '	$file .= $line . "\n";'
    echo "}"
    echo "#"
    echo "#"close FILE;
    echo "#"
    echo "open (FILE,\">${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo 'print FILE "$file";'
    echo "close FILE;"
    ) >${TARGET}
fi

#------------------------------------------------------------------------------
#
# Create an example dhcpd config file
#
SOURCE=/etc/dhcpd.conf.example
TARGET=${TMPL_DIR}/dhcp_conf.tmpl
logit "Setting up ${TARGET}"

if [ "${VERSION}" = "7.0" \
  -o "${VERSION}" = "7.1" \
  -o "${VERSION}" = "7.2" \
  -o "${VERSION}" = "7.3" \
  -o "${VERSION}" = "8.0" ]; then 
	SAVE_LTSP_DIR=${LTSP_DIR}
	LTSP_DIR=`echo ${LTSP_DIR} | sed 's/\/tftpboot//'`
fi

    
(
    echo "# Sample configuration file for ISCD dhcpd"
    echo "#"
    echo "# Don't forget to set run_dhcpd=1 in /etc/init.d/dhcpd"
    echo "# once you adjusted this file and copied it to /etc/dhcpd.conf."
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=\"Example config file for dhcp\""
    echo "# DESC_KEY=dhcpd.conf"
    echo "# ACTION=COPY,0640,root,root"
    echo "#"
    echo
    echo "ddns-update-style             none;"
    echo "default-lease-time            21600;"
    echo "max-lease-time                21600;"
    echo
    echo "option subnet-mask            ${IP_NETMASK};"
    echo "option broadcast-address      ${IP_BROADCAST};"
    echo "option routers                ${IP_SERVER};"
    echo "option domain-name-servers    ${IP_SERVER};"
    echo "option domain-name            \"yourdomain.com\";"
    echo "option root-path              \"${IP_SERVER}:${ROOT_DIR}\";"
    echo
    echo "option option-128 code 128 = string;"
    echo "option option-129 code 129 = text;"
    echo
    echo "shared-network WORKSTATIONS {"
    echo "    subnet ${IP_NETWORK} netmask ${IP_NETMASK} {"
    echo "    }"
    echo "}"
    echo
    echo "group	{"
    echo "    use-host-decl-names       on;"
    echo "    option log-servers        ${IP_SERVER};"
    echo ""
    echo "    host ws001 {"
    echo "        hardware ethernet     00:E0:06:E8:00:84;"
    echo "        fixed-address         ${IP_NETWORK_BASE}.1;"
    echo "        filename              \"/lts/vmlinuz-2.4.9-ltsp-6\";"
    echo "        option option-128     e4:45:74:68:00:00;"
    echo "        option option-129     \"NIC=eepro100\";"
    echo "    }"
    echo "    host ws002 {"
    echo "        hardware ethernet     00:D0:09:30:6A:1C;"
    echo "        fixed-address         ${IP_NETWORK_BASE}.2;"
    echo "        filename              \"/lts/vmlinuz-2.4.9-ltsp-6\";"
    echo "        option option-128     e4:45:74:68:00:00;"
    echo "        option option-129     \"NIC=tulip\";"
    echo "    }"
    echo "}"
) >${TARGET}

LTSP_DIR=${SAVE_LTSP_DIR}

#------------------------------------------------------------------------------
# DHCP-SERVER 
#
# Setup the rc scripts so that dhcpd will start when server boots
# creates softlink in rc.d to start the dhcpd
# there is no more rc.config in SuSE 8.0

if [ "$VERSION" = "8.0" ]; then

    SOURCE=/etc/rc.d/rc5.d/S12dhcpd
    TARGET=${TMPL_DIR}/dhcpd.tmpl
    logit "Setting up ${TARGET}"

(
    echo ":"
    echo "#"
    echo '# The Linux Terminal Server Project - (http://www.ltsp.org)'
    echo "#"
    echo "# This script will check to see if there is a startup script"
    echo "# to start the dhcp daemon"
    echo "#"
    echo "# This shell script is normally run by the ltsp_initialize script."
    echo "#"
    echo ""
    echo "TARGET=${SOURCE}"
    echo "DEFAULT=Y"
    echo "DESCRIPTION=\"Startup links for DHCPD\""
    echo "DESC_KEY=dhcpd"
    echo ""
    echo "chkconfig dhcpd 35"
    echo "exit 0"
    ) >${TARGET}

    chmod 0644      ${TARGET}
    chown root:root ${TARGET}

else

#------------------------------------------------------------------------------
#
# Setup the dhcp-server in rc.config for SuSE < 7.3
#
    SOURCE=/etc/rc.config
    TARGET=${TMPL_DIR}/dhcpd.tmpl
    logit "Setting up ${TARGET}"

    (
    echo "#!/usr/bin/perl -w"
    echo "# TARGET=${SOURCE}"
    echo "# DEFAULT=Y"
    echo "# DESCRIPTION=Start dhcp daemon in rc.config"
    echo "# DESC_KEY=rc.config_dhcpd"
    echo "# ACTION=BACKUP_EXECUTE"
    echo "#"
    echo "# Open config file read only, change what we need to and store it in"
    echo '# $file. Then close this config file and rewrite it new with'
    echo '# the stuff from $file.'
    echo "#"
    echo "open (FILE,\"<${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo "#"
    echo 'while ($line = <FILE>) {'
    echo '	chomp($line);'
    echo '	$line =~ s/^START_DHCPD\s*=\s*"?[Nn][Oo]"?.*/START_DHCPD="yes"/;'
    echo '	$file .= $line . "\n";'
    echo "}"
    echo "#"
    echo "#"close FILE;
    echo "#"
    echo "open (FILE,\">${SOURCE}\")"
    echo '	or die "\n$!\n";'
    echo 'print FILE "$file";'
    echo "close FILE;"
    ) >${TARGET}

fi

#
##############################################################################

##############################################################################
#
# ok, seems to me we are finished!
#
logit "\nDone with $0\n"
#
if [ "${QUIET_MODE}" != "Y" ]; then
    echo
    echo "Take a look in ${LOGFILE} for a complete log of the installation"
    echo
    echo "You now need to change to the ${TMPL_DIR} directory and"
    echo "run the ltsp_initialize script to complete the installation"
    echo
fi
#
##############################################################################
